@@ -2,7 +2,7 @@
 """
  **********************************************************
  * Author        : tianshl
- * Email         : email@example.com
+ * Email         : xiyuan91@126.com
  * Last modified : 2020-06-30 17:18:33
  * Filename      : wizard.py
  * Description   : XX精灵: 录制鼠标键盘操作, 回放录制的脚本
@@ -873,6 +873,12 @@ class Wizard(Frame):
         log.info('启动热键监听')
         threading.Thread(target=self.hot_key_listener, daemon=True).start()
 
+    def run(self):
+        """
+        运行
+        """
+        self.mainloop()
+
 
 if __name__ == '__main__':
-    Wizard().mainloop()
+    Wizard().run()
